@@ -155,6 +155,26 @@ class makefile:
                     f"oShell.Run \"{item}\"\n"
                     )
 
+    def createshortcut(self, filepath, lnkpath, icon, shrtname="shortcut"):
+        if isinstance(icon, int):
+            icon = "%SystemRoot%\System32\SHELL32.dll," + str(icon)
+            with open(f'{str(Path(__file__).absolute())[:-11]}\\files\\{self.filename}.vbs', 'a') as f:
+                f.write("Set obj = createObject(\"wscript.shell\")\n"
+                        f"Set shrt = obj.CreateShortcut(\"{os.path.abspath(lnkpath+ shrtname + '.lnk')}\")\n"
+                        f"shrt.TargetPath = \"{os.path.abspath(filepath)}\"\n"
+                        f"shrt.IconLocation = \"{icon}\"\n"
+                        "shrt.Save\n"
+                )
+
+            with open(f'{str(Path( __file__ ).absolute())[:-11]}\\files\\{self.filename}.vbs', 'a') as f:
+                f.write("Set obj = createObject(\"wscript.shell\")\n"
+                f"Set shrt = obj.CreateShortcut(\"{os.path.abspath(lnkpath)}\")\n"
+                f"shrt.TargetPath = {filepath}\n"
+                f"shrt.IconLocation = \"{os.path.abspath(icon)}\"\n"
+                "shrt.Save\n"
+                    )
+
+
     def input(self, text=None, title=None, getvar=True): #pretty much the same as msgbox
         if text == None: text = ""
         if title == None: title = ""
@@ -696,6 +716,14 @@ def specialfolder(folder=None, getvar=True):
         return
     file.run()
 
+
+def createshortcut(filepath, lnkpath, icon, shrtname="shortcut"):
+    file = makefile()
+
+    file.createshortcut(filepath, lnkpath, icon, shrtname)
+
+    file.run(deletefile=False)
+
 class itemattributes:
     class tts:
         def voice_1(self):
